export class SettingsApp {
  constructor() {
    this.container = null;
    this.loginAttempts = 0;
    this.registerAttempts = 0;
    this.isLoading = false;
    this.isLoggedIn = false;
    this.currentUser = null;
  }

  async initialize(container) {
    if (!container) {
      console.error('未提供容器元素');
      return;
    }

    this.container = container;
    this.checkLoginStatus();
    this.createSettingsUI();
    this.bindEvents();
  }

  checkLoginStatus() {
    const isLoggedIn = localStorage.getItem('isLoggedIn') === 'true';
    const username = localStorage.getItem('username');
    if (isLoggedIn && username) {
      this.isLoggedIn = true;
      this.currentUser = { username };
    }
  }

  createSettingsUI() {
    if (this.isLoggedIn) {
      this.createLoggedInUI();
    } else {
      this.createLoginUI();
    }
  }

  createLoginUI() {
    this.container.innerHTML = ``;
  }

  createLoggedInUI() {
    this.container.innerHTML = ``;
  }

  bindEvents() {
    if (this.isLoggedIn) {
      this.bindLoggedInEvents();
    } else {
      this.bindLoginEvents();
    }
  }

  bindLoginEvents() {
    const showRegisterBtn = this.container.querySelector('#showRegisterBtn');
    const registerModal = this.container.querySelector('#registerModal');
    const closeRegisterBtn = registerModal?.querySelector('.modal-close');
    console.log(closeRegisterBtn);

    showRegisterBtn?.addEventListener('click', () => {
      registerModal?.classList.add('active');
    });

    closeRegisterBtn?.addEventListener('click', () => {
      console.log(registerModal);
      registerModal?.classList.remove('active');
    });

    const loginForm = this.container.querySelector('#loginForm');
    loginForm?.addEventListener('submit', async (e) => {
      e.preventDefault();
      await this.handleLogin();
    });

    const registerForm = this.container.querySelector('#registerForm');
    registerForm?.addEventListener('submit', async (e) => {
      e.preventDefault();
      await this.handleRegister();
    });
    // 添加登录表单验证码刷新按钮事件监听器
    const loginRefreshCaptchaBtn = this.container.querySelector('#loginForm .refresh-captcha');
    loginRefreshCaptchaBtn?.addEventListener('click', () => {
      this.generateCaptcha('loginCaptchaCanvas');
    });

    // 添加注册表单验证码刷新按钮事件监听器
    const registerRefreshCaptchaBtn = this.container.querySelector('#registerForm .refresh-captcha');
    registerRefreshCaptchaBtn?.addEventListener('click', () => {
      this.generateCaptcha('registerCaptchaCanvas');
    });
  }

  bindLoggedInEvents() {
    const logoutBtn = this.container.querySelector('.logout-btn');
    const changePasswordBtn = this.container.querySelector('.change-password-btn');
    const passwordModal = this.container.querySelector('#passwordModal');
    const closePasswordBtn = passwordModal?.querySelector('.modal-close');

    logoutBtn?.addEventListener('click', () => this.handleLogout());

    changePasswordBtn?.addEventListener('click', () => {
      passwordModal?.classList.add('active');
    });

    closePasswordBtn?.addEventListener('click', () => {
      passwordModal?.classList.remove('active');
    });

    const changePasswordForm = this.container.querySelector('#changePasswordForm');
    changePasswordForm?.addEventListener('submit', (e) => {
      e.preventDefault();
      this.handleChangePassword();
    });
  }

  handleLogout() {
    if (confirm('确定要退出登录吗？')) {
      localStorage.removeItem('isLoggedIn');
      localStorage.removeItem('username');
      this.isLoggedIn = false;
      this.currentUser = null;
      this.createLoginUI();
      this.bindLoginEvents();
    }
  }

  async handleChangePassword() {
    const currentPassword = this.container.querySelector('#currentPassword').value;
    const newPassword = this.container.querySelector('#newPassword').value;
    const confirmNewPassword = this.container.querySelector('#confirmNewPassword').value;

    if (newPassword !== confirmNewPassword) {
      this.showError('两次输入的新密码不一致');
      return;
    }

    try {
      const success = await this.changePassword(currentPassword, newPassword);
      if (success) {
        this.showSuccess('密码修改成功');
        this.container.querySelector('#passwordModal').classList.remove('active');
        this.container.querySelector('#changePasswordForm').reset();
      } else {
        this.showError('当前密码错误');
      }
    } catch (error) {
      this.showError('修改密码失败，请重试');
    }
  }

  formatDate(date) {
    return new Intl.DateTimeFormat('zh-CN', {
      year: 'numeric',
      month: '2-digit',
      day: '2-digit',
      hour: '2-digit',
      minute: '2-digit'
    }).format(date);
  }

  async handleLogin() {
    const username = this.container.querySelector('#loginUsername').value.trim();
    const password = this.container.querySelector('#loginPassword').value;
    const captchaInput = this.container.querySelector('#loginCaptcha');
    const submitBtn = this.container.querySelector('#loginForm .auth-submit');

    if (!this.validateLoginForm(username, password)) {
      return;
    }

    if (this.loginAttempts >= 1) {
      const captchaValue = captchaInput?.value?.trim();
      if (!captchaValue) {
        this.showError('请输入验证码');
        return;
      }
      if (!this.validateCaptcha('loginCaptchaCanvas', captchaValue)) {
        this.showError('验证码错误');
        this.generateCaptcha('loginCaptchaCanvas');
        return;
      }
    }

    try {
      this.setLoading(true, submitBtn);
      const success = await this.loginUser(username, password);

      if (!success) {
        this.loginAttempts++;
        if (this.loginAttempts >= 1) {
          const captchaGroup = this.container.querySelector('#loginForm .captcha-group');
          captchaGroup.style.display = 'block';
          this.generateCaptcha('loginCaptchaCanvas');
          captchaInput?.focus();
        }
        this.showError('用户名或密码错误');
      } else {
        this.showSuccess('登录成功');
        this.loginAttempts = 0;

        localStorage.setItem('isLoggedIn', 'true');
        localStorage.setItem('username', username);

        this.isLoggedIn = true;
        this.currentUser = {
          username,
          lastLoginTime: new Date().toISOString()
        };

        this.createLoggedInUI();
        this.bindLoggedInEvents();
      }
    } catch (error) {
      this.showError('登录失败，请重试');
    } finally {
      this.setLoading(false, submitBtn);
    }
  }

  validateLoginForm(username, password) {
    if (!username) {
      this.showError('请输入用户名');
      return false;
    }
    if (!password) {
      this.showError('请输入密码');
      return false;
    }
    return true;
  }

  async loginUser(username, password) {
    return new Promise(resolve => {
      setTimeout(() => {
        const validUsers = {
          'admin': 'admin123',
          'test': 'test123'
        };
        const success = validUsers[username] === password;
        resolve(success);
      }, 1000);
    });
  }

  showError(message) {
    const errorDiv = document.createElement('div');
    errorDiv.className = 'auth-error';
    errorDiv.textContent = message;

    const existingError = this.container.querySelector('.auth-error');
    if (existingError) {
      existingError.remove();
    }

    const authContainer = this.container.querySelector('.auth-form');
    if (authContainer) {
      authContainer.insertBefore(errorDiv, authContainer.firstChild);
    }

    setTimeout(() => errorDiv.remove(), 3000);
  }

  showSuccess(message) {
    const successDiv = document.createElement('div');
    successDiv.className = 'auth-success';
    successDiv.textContent = message;

    const authContainer = this.container.querySelector('.auth-form');
    if (authContainer) {
      authContainer.insertBefore(successDiv, authContainer.firstChild);
    }

    setTimeout(() => successDiv.remove(), 3000);
  }

  generateCaptcha(canvasId) {
    const canvas = this.container.querySelector(`#${canvasId}`);
    if (!canvas) return;

    const context = canvas.getContext('2d');
    const captchaText = Math.random().toString(36).substring(2, 8).toUpperCase();

    canvas.dataset.captcha = captchaText;

    context.clearRect(0, 0, canvas.width, canvas.height);

    context.fillStyle = '#f0f0f0';
    context.fillRect(0, 0, canvas.width, canvas.height);

    context.font = '24px Arial';
    context.fillStyle = '#333';
    context.textBaseline = 'middle';
    context.textAlign = 'center';

    for (let i = 0; i < 3; i++) {
      context.beginPath();
      context.moveTo(Math.random() * canvas.width, Math.random() * canvas.height);
      context.lineTo(Math.random() * canvas.width, Math.random() * canvas.height);
      context.strokeStyle = `rgb(${Math.random() * 255},${Math.random() * 255},${Math.random() * 255})`;
      context.stroke();
    }

    for (let i = 0; i < 30; i++) {
      context.beginPath();
      context.arc(Math.random() * canvas.width, Math.random() * canvas.height, 1, 0, 2 * Math.PI);
      context.fillStyle = `rgb(${Math.random() * 255},${Math.random() * 255},${Math.random() * 255})`;
      context.fill();
    }

    for (let i = 0; i < captchaText.length; i++) {
      const x = (i + 1) * (canvas.width / (captchaText.length + 1));
      const y = canvas.height / 2;
      const rotation = (Math.random() - 0.5) * 0.3;
      context.save();
      context.translate(x, y);
      context.rotate(rotation);
      context.fillText(captchaText[i], 0, 0);
      context.restore();
    }
  }

  validateCaptcha(canvasId, input) {
    const canvas = this.container.querySelector(`#${canvasId}`);
    return canvas?.dataset.captcha === input.toUpperCase();
  }

  setLoading(isLoading, button) {
    this.isLoading = isLoading;
    if (button) {
      button.disabled = isLoading;
      const originalText = button.dataset.originalText || button.textContent;

      if (isLoading) {
        button.innerHTML = `
          <span class="loading-spinner"></span>
          <span>处理中...</span>
        `;
      } else {
        button.textContent = originalText;
      }
    }
  }

  async changePassword(currentPassword, newPassword) {
    return new Promise(resolve => {
      setTimeout(() => {
        const validUsers = {
          'admin': 'admin123',
          'test': 'test123'
        };
        const username = this.currentUser?.username;
        const success = validUsers[username] === currentPassword;
        if (success) {
          validUsers[username] = newPassword;
        }
        resolve(success);
      }, 1000);
    });
  }
}


{
  // 添加消息监听器
  chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {

    //获取所有企业信息--来自--popup的请求，
    if (request.action === 'getallissuce') {
      return handleGetAllIssuce(request, sendResponse);
    }

    // 可以添加其他请求处理逻辑
    return false;
  });

  // 封装获取所有企业信息的逻辑
  async function handleGetAllIssuce(request, sendResponse) {
    console.log("收到侧栏发来的信息", request);
    try {
      // 确定服务器状态
      const okserver = await serveok();
      console.log(okserver);

      if (okserver) {
        // 请求 get 的数据函数
        const allissucedata = await getallissucefun();
        const data = allissucedata.data;
        // 在这里可以使用 data 数组对象进行后续操作
        console.log(data);
        // 拿到数据后在后台脚本中发送消息给 popup
        sendResponse({ getallissuce: data });
      } else {
        sendResponse({ getallissuce: '网络异常' });
      }
    } catch (error) {
      // 处理 Promise 的错误
      console.error('An error occurred:', error);
      sendResponse({ getallissuce: '请求出错，请稍后重试' });
    }
    return true; // 必须返回 true 才能异步发送响应
  }

  // 优化获取所有企业信息的请求函数
  async function getallissucefun() {
    console.log('名单--获取所有信息');
    const resumurl = `${baseUrl}/api/resume/getallissuce`;
    try {
      const response = await fetch(resumurl, {
        method: 'GET',
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
        }
      });
      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }
      const data = await response.json();
      console.log(data);
      console.log(data.status);
      console.log(data.data);
      return data;
    } catch (error) {
      console.error('Error:', error);
      throw error;
    }
  }




}